%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Author: Harsh Sapra
% Date: 25-9-2019
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear all; 
close all; 
warning off; 
clc;

current_directory = cd;

%% Fuel Blend Input

HCO2  = '2';            % if 0 then just Natural gas, if 1 then only H blend, if 2 then only CO2 blend, if 3 then H and CO2 blend
H_f   = 0;              % Hydrogen fraction for calculation 
CO2_f = 20;              % CO2 fraction for calculation
NG_f  = 100-(H_f + CO2_f); 
Load  = 250;             % [kW] Load input


%% Load Measurements for Comparison

load('MVEM_Data');

%%%% Notes%%%%

%%% 1.) Use unit delay after MAP_initial limit in Sim model of MAP_Close Control
%%% @ 500 kW and following blend: 20% CO2 and 10%H. 
%%% Anything lower with CO2 (alone or blend) the model works perfectly w/o unit delay


%% LOAD PARAMETERS
% % load engine, gas, fuel and water properties

cd([cd,'/Properties']); 
Common_properties;
Ambient_condition;    
Fuel_properties; 
Water_properties;
Gas_properties;

cd(current_directory)

cd([cd,'/CATG3508']);           % Engine

Engine_data;                 
Inlet_manifold;
Cylinder_data;
Turbocharger_data;

cd(current_directory);

%% MAP Control
MAP_Control = 0; % If MAP_Control = 1 Fixed MAP; If MAP_Control = 0 Variable MAP

%% SIMULATION
PLOT.nr_P       = 5;   % Plot steps %%% 5 works for all till 20% CO2 and 10% H @ 500 kW

t_begin         = 0;
t_end           = 100*PLOT.nr_P; 
% t_end           = 1.9*PLOT.nr_P; %% for 750 kW only

%% Simulation
tic

open ('AOG_NG_MVEM.slx')
sim('AOG_NG_MVEM.slx')

toc

%% GRAPHICS

CAT_sim_p = [p1_Corr.Data(end) p_2(end) p_3(end) p_4(end) p_5(end) p_6(end)];
CAT_sim_T = [T1_Corr(end) T_2(end) T_3(end) T_4(end) T_5(end) T_6(end)];
CAT_sim_V = [GE_CATG3508.V1 V_2(end) V_3(end) V_4(end) V_5(end) V_6(end)];
CAT_sim_divp = [DE_p_d_50(end) DE_pBT_50(end) p1_Corr.Data(end) p1_Corr.Data(end) p_3(end) p_6(end)]; %[Pa]
CAT_sim_divT = [DE_T_d_50(end) DE_T_e_50(end) T1_Corr(end) T_4(end) T_6(end)]; %[K]

display('PB [kW]') 
display(Brake_power(end)/1000) %[kW]Power
display('Efficiency') 
display(Efficiency(end)*100)    %[-] efficiency




%% Plots
Plots_81019

