%% In-cylinder Process

%%% Air
GE_CATG3508.afr      = GE_CATG3508.lambda*fuel.sigma;      % air-fuel ratio
GE_CATG3508.m_air    = GE_CATG3508.afr*GE_CATG3508.m_Fuel; % mass of air per cycle per cylinder

%%% Trapped pressure
GE_CATG3508.p1_int       = GE_CATG3508.MAP_int;                          % Trapped pressure 
GE_CATG3508.p1_nom       = 1.61*10^5;                          % Trapped pressure 
%%% Trapped Volume
GE_CATG3508.V1       = GE_CATG3508.V_IC;

%%% Trapped mass
GE_CATG3508.m1       = (GE_CATG3508.p1_int*GE_CATG3508.V1)/(GE_CATG3508.R_mix*GE_CATG3508.T1);
GE_CATG3508.m1_int   = GE_CATG3508.m1;
GE_CATG3508.m1_nom   = (GE_CATG3508.p1_nom*GE_CATG3508.V1)/(GE_CATG3508.R_mix*GE_CATG3508.T1_nom);
 
%%% Mass fractions
GE_CATG3508.m_sg =  GE_CATG3508.m1 - (GE_CATG3508.m_air + GE_CATG3508.m_Fuel);
GE_CATG3508.x_sg_int = GE_CATG3508.m_sg/GE_CATG3508.m1;
GE_CATG3508.x_f_nom = GE_CATG3508.m_Fuel/GE_CATG3508.m1_nom;
GE_CATG3508.x_f_int = GE_CATG3508.m_Fuel/GE_CATG3508.m1;
GE_CATG3508.x_air_int = GE_CATG3508.m_air/GE_CATG3508.m1;

% Thermodynamic properties trapped condition
R_cyl     = air.R*GE_CATG3508.x_air_int + sg.R*GE_CATG3508.x_sg_int + fuel.R*GE_CATG3508.x_f_int;


%% Seiliger Process
%%% a
% Only Natural Gas fuel regression (Benchmark) + Regression input
a_seila =     -0.0837;
b_seila =      2.318;
c_seila =      1.448;

a_NG = a_seila*NGFM_norm^b_seila+c_seila;

% a %CO2
p00_aCO2 =  -0.07639 ;  % wCO2
p10_aCO2 =   0.2275;
p01_aCO2 =  -0.2426;
p20_aCO2 =  -0.1414;
p11_aCO2 =   0.06626;
p02_aCO2 =   0.894;

D_aCO2 = p00_aCO2 + p10_aCO2*x + p01_aCO2*y_CO2 + p20_aCO2*x^2 + p11_aCO2*x*y_CO2 + p02_aCO2*y_CO2^2; % Delta 'a' for CO2 blend
aCO2 = a_NG + D_aCO2; % 'a' for CO2 blend

% a %H
p00_aH = -0.169;  
p10_aH =  0.4481;
p01_aH =  0.815;
p20_aH = -0.2938;
p11_aH = -0.092;
p02_aH = -0.4845;

D_aH = p00_aH + p10_aH*x + p01_aH*y_H + p20_aH*x^2 + p11_aH*x*y_H + p02_aH*y_H^2; % Delta 'a' for H2 blend
aH = a_NG + D_aH; % 'a' for CO2 blend

aHCO2     = a_NG + D_aH + D_aCO2; % Seiliger combustion at constant volume

if strcmp(HCO2,'0')==1;
    GE_CATG3508.a = a_NG;
elseif strcmp(HCO2,'1')==1;
    GE_CATG3508.a = aH;
elseif strcmp(HCO2,'2')==1;
    GE_CATG3508.a = aCO2;
else strcmp(HCO2,'3')==1;
    GE_CATG3508.a = aHCO2;
end

%%% b
% Only Natural Gas fuel regression (Benchmark) + Regression input
a_seilb =    0.317;
b_seilb =    0.2943;
c_seilb =    1.135;

b_NG = a_seilb*NGFM_norm^b_seilb+c_seilb;

% b %CO2
p00_bCO2 =  0.03385; 
p10_bCO2 = -0.05966;
p01_bCO2 = -0.06964;
p20_bCO2 =  0.01828;
p11_bCO2 =  0.25; 
p02_bCO2 = -0.258;

D_bCO2 = p00_bCO2 + p10_bCO2*x + p01_bCO2*y_CO2 + p20_bCO2*x^2 + p11_bCO2*x*y_CO2 + p02_bCO2*y_CO2^2; % Delta 'b' for CO2 blend
bCO2 = b_NG + D_bCO2; % 'b' for CO2 blend

% b %H
p00_bH =  0.1339; 
p10_bH = -0.29951;
p01_bH = -0.9673;
p20_bH =  0.1882;
p11_bH = -0.0354; 
p02_bH =  1.583;

D_bH = p00_bH + p10_bH*x + p01_bH*y_H + p20_bH*x^2 + p11_bH*x*y_H + p02_bH*y_H^2; % Delta 'b' for H2 blend
bH = b_NG + D_bH; % 'b' for H2 blend

bHCO2     = b_NG + D_bH + D_bCO2; % Seiliger combustion at constant pressure

if strcmp(HCO2,'0')==1;
    GE_CATG3508.b = b_NG;
elseif strcmp(HCO2,'1')==1;
    GE_CATG3508.b = bH;
elseif strcmp(HCO2,'2')==1;
    GE_CATG3508.b = bCO2;
else strcmp(HCO2,'3')==1;
    GE_CATG3508.b = bHCO2;
end

%%% c
% Only Natural Gas fuel regression (Benchmark) + Regression input
a_seilc =    0.2688;
b_seilc =    1.566;
c_seilc =    1.523;

c_NG = a_seilc*NGFM_norm^b_seilc+c_seilc;

% c %CO2
p00_cCO2 =  0.03342;
p10_cCO2 = -0.2332;
p01_cCO2 =  1.098;
p20_cCO2 =  0.171;
p11_cCO2 = -0.5117; 
p02_cCO2 = -2.81; 

D_cCO2 = p00_cCO2 + p10_cCO2*x + p01_cCO2*y_CO2 + p20_cCO2*x^2 + p11_cCO2*x*y_CO2 + p02_cCO2*y_CO2^2; % Delta 'c' for CO2 blend
cCO2 = c_NG + D_cCO2; % 'c' for CO2 blend

% c %H
p00_cH =  0.08155;  
p10_cH = -0.5649;
p01_cH =  1.029;
p20_cH =  0.4371;
p11_cH = -0.5361; 
p02_cH = -4.066;

D_cH = p00_cH + p10_cH*x + p01_cH*y_H+ p20_cH*x^2 + p11_cH*x*y_H+ p02_cH*y_H^2; % Delta 'c' for H2 blend
cH = c_NG + D_cH; % 'c' for H2 blend

cHCO2    = c_NG + D_cH + D_cCO2; % Seiliger combustion at constant temperature

if strcmp(HCO2,'0')==1;
    GE_CATG3508.c = c_NG;
elseif strcmp(HCO2,'1')==1;
    GE_CATG3508.c = cH;
elseif strcmp(HCO2,'2')==1;
    GE_CATG3508.c = cCO2;
else strcmp(HCO2,'3')==1;
    GE_CATG3508.c = cHCO2;
end

%%% n_exp
% Only Natural Gas fuel regression (Benchmark) + Regression input
a_seiln_exp =     1.259;
b_seiln_exp =    -0.002199;
c_seiln_exp =     0.03705;

n_exp_NG = a_seiln_exp*NGFM_norm^b_seiln_exp+c_seiln_exp;

% n_exp %CO2
p00_n_expCO2 =  -0.01053; 
p10_n_expCO2 =   0.01147;
p01_n_expCO2 =   0.1443;
p20_n_expCO2 =  -0.008184;
p11_n_expCO2 =  -0.03203;
p02_n_expCO2 =  -0.4675;

D_n_expCO2 = p00_n_expCO2 + p10_n_expCO2*x + p01_n_expCO2*y_CO2 + p20_n_expCO2*x^2 + p11_n_expCO2*x*y_CO2 + p02_n_expCO2*y_CO2^2; % Delta 'n_exp' for CO2 blend
n_expCO2 = n_exp_NG + D_n_expCO2; % 'n_exp' for CO2 blend

% n_exp %H2
p00_n_expH =  -8.209e-05; 
p10_n_expH =  -0.006287;
p01_n_expH =   0.02976;
p20_n_expH =   0.00471;
p11_n_expH =   0.01185;
p02_n_expH =  -0.09723;

D_n_expH = p00_n_expH + p10_n_expH*x + p01_n_expH*y_H+ p20_n_expH*x^2 + p11_n_expH*x*y_H + p02_n_expH*y_H^2; % Delta 'n_exp' for H2 blend
n_expH = n_exp_NG + D_n_expH; % 'n_exp' for H2 blend

n_expHCO2     = n_exp_NG + D_n_expH + D_n_expCO2;         % [-] polytropic exponent for expansion in cylinder

if strcmp(HCO2,'0')==1;
    GE_CATG3508.n_exp = n_exp_NG;
elseif strcmp(HCO2,'1')==1;
    GE_CATG3508.n_exp = n_expH;
elseif strcmp(HCO2,'2')==1;
    GE_CATG3508.n_exp = n_expCO2;
else strcmp(HCO2,'3')==1;
    GE_CATG3508.n_exp = n_expHCO2;
end

%%% n_comp
% Only Natural Gas fuel regression (Benchmark) + Regression input
a_seiln_c =     1.09;
b_seiln_c =    -0.005154;
c_seiln_c =     0.2408;

n_c_NG = a_seiln_c*NGFM_norm^b_seiln_c+c_seiln_c;

% n_comp %CO2
p00_n_cCO2 =  0.004347; 
p10_n_cCO2 = -0.000627;
p01_n_cCO2 = -0.1173;
p20_n_cCO2 =  0.00382;
p11_n_cCO2 = -0.03661;
p02_n_cCO2 =  0.5972;

D_n_cCO2 = p00_n_cCO2 + p10_n_cCO2*x + p01_n_cCO2*y_CO2+ p20_n_cCO2*x^2 + p11_n_cCO2*x*y_CO2 + p02_n_cCO2*y_CO2^2; % Delta 'n_c' for CO2 blend
n_cCO2 = n_c_NG + D_n_cCO2; % 'n_c' for CO2 blend

% n_comp %H2
p00_n_cH =  0.0008963; 
p10_n_cH = -0.005912;
p01_n_cH =  0.01317;
p20_n_cH =  0.005105;
p11_n_cH = -0.005906;
p02_n_cH = -0.02072;

D_n_cH = p00_n_cH + p10_n_cH*x + p01_n_cH*y_H+ p20_n_cH*x^2 + p11_n_cH*x*y_H + p02_n_cH*y_H^2; % Delta 'n_c' for H2 blend
n_cH = n_c_NG + D_n_cH; % 'n_c' for H2 blend

n_cHCO2     = n_c_NG + D_n_cH + D_n_cCO2;         % [-] polytropic exponent for compression in cylinder

if strcmp(HCO2,'0')==1;
    GE_CATG3508.n_com = n_c_NG;
elseif strcmp(HCO2,'1')==1;
    GE_CATG3508.n_com = n_cH;
elseif strcmp(HCO2,'2')==1;
    GE_CATG3508.n_com = n_cCO2;
else strcmp(HCO2,'3')==1;
    GE_CATG3508.n_com = n_cHCO2;
end

%%% Combustion Efficiency
% Only Natural Gas fuel regression (Benchmark) + Regression input
a_seileta_comb =     1.004;
b_seileta_comb =    0.000521;
c_seileta_comb =    -0.02606;

eta_comb_NG = a_seileta_comb*NGFM_norm^b_seileta_comb+c_seileta_comb;

% eta_comb %CO2
p00_eta_combCO2 =  -0.0009629; 
p10_eta_combCO2 =   0.00365;
p01_eta_combCO2 =   0.02314;
p20_eta_combCO2 =  -0.002188;
p11_eta_combCO2 =  -0.01971;
p02_eta_combCO2 =  -0.02686;

D_eta_combCO2 = p00_eta_combCO2 + p10_eta_combCO2*x + p01_eta_combCO2*y_CO2 + p20_eta_combCO2*x^2 + p11_eta_combCO2*x*y_CO2 + p02_eta_combCO2*y_CO2^2; % Delta 'eta_comb' for CO2 blend
eta_combCO2 = eta_comb_NG + D_eta_combCO2; % 'eta_comb' for CO2 blend

% eta_comb %H2
p00_eta_combH =   -0.004554; 
p10_eta_combH =   0.01242;
p01_eta_combH =   0.00841;
p20_eta_combH =  -0.007506;
p11_eta_combH =  -0.01571;
p02_eta_combH =   0.01627;

D_eta_combH = p00_eta_combH + p10_eta_combH*x + p01_eta_combH*y_H+ p20_eta_combH*x^2 + p11_eta_combH*x*y_H + p02_eta_combH*y_H^2; % Delta 'eta_comb' for H2 blend
eta_combH = eta_comb_NG + D_eta_combH; % 'eta_comb' for H2 blend

eta_combHCO2     = eta_comb_NG + D_eta_combH + D_eta_combCO2;

if strcmp(HCO2,'0')==1;
    GE_CATG3508.eta_comb = eta_comb_NG;
elseif strcmp(HCO2,'1')==1;
    GE_CATG3508.eta_comb = eta_combH;
elseif strcmp(HCO2,'2')==1;
    GE_CATG3508.eta_comb = eta_combCO2;
else strcmp(HCO2,'3')==1;
    GE_CATG3508.eta_comb = eta_combHCO2;
end

%%% UHC_ppmv

a_UHC =     -768.6;
b_UHC =     0.1512;
c_UHC =      1741;

UHC_NG = a_UHC*NGFM_norm^b_UHC + c_UHC;

p00_UHCCO2 =  -0.01053; % wCO2
p10_UHCCO2 =  -136.4;
p01_UHCCO2 =  -2082;
p20_UHCCO2 =  102.5;
p11_UHCCO2 =  985.6;
p02_UHCCO2 =  6055;

D_UHCCO2 = p00_UHCCO2 + p10_UHCCO2*x + p01_UHCCO2*y_CO2 + p20_UHCCO2*x^2 + p11_UHCCO2*x*y_CO2 + p02_UHCCO2*y_CO2^2;
UHCCO2 = UHC_NG + D_UHCCO2; 

p00_UHC7520H =  180.7; % w7520H
p10_UHC7520H =  -436;
p01_UHC7520H =  -1303;
p20_UHC7520H =  248.1;
p11_UHC7520H =  783.4;
p02_UHC7520H =  129.2;


D_UHCH = p00_UHC7520H + p10_UHC7520H*x + p01_UHC7520H*y_H+ p20_UHC7520H*x^2 + p11_UHC7520H*x*y_H + p02_UHC7520H*y_H^2;
UHCH = UHC_NG + D_UHCH; 

UHCHCO2 = UHC_NG + D_UHCH + D_UHCCO2;


if strcmp(HCO2,'0')==1;
    GE_CATG3508.UHC = UHC_NG;
elseif strcmp(HCO2,'1')==1;
    GE_CATG3508.UHC = UHCH;
elseif strcmp(HCO2,'2')==1;
    GE_CATG3508.UHC = UHCCO2;
else strcmp(HCO2,'3')==1;
    GE_CATG3508.UHC = UHCHCO2;
end

% GE_CATG3508.eta_comb  = 0.979;          % Combustion efficiency NG


%% Seiliger Process: In-cylinderr thermodynamic properties

% process 1-2; isentropic compression
     
    GE_CATG3508.V2        = GE_CATG3508.V1/GE_CATG3508.r_c;                         % [m3] min volume
    GE_CATG3508.p2_int    = GE_CATG3508.p1_int*GE_CATG3508.r_c^(GE_CATG3508.n_com); % [Pa] pressure after compression
    GE_CATG3508.T2        = GE_CATG3508.T1*GE_CATG3508.r_c^(GE_CATG3508.n_com-1);   % [K] temperature after compression
    
    % thermodynamic properties T1
    T = GE_CATG3508.T1;
    cp_a_1 = air.cp(1)+air.cp(2)*(T/1000)+air.cp(3)*(T/1000)^2+air.cp(4)*(T/1000)^3+air.cp(5)*(T/1000)^4+air.cp(6)*(T/1000)^5;
    cp_sg_1 = sg.cp(1)+sg.cp(2)*(T/1000)+sg.cp(3)*(T/1000)^2+sg.cp(4)*(T/1000)^3+sg.cp(5)*(T/1000)^4+sg.cp(6)*(T/1000)^5;
    cp_fuel_1 = fuel.cp(1)+fuel.cp(2)*(T/1000)+fuel.cp(3)*(T/1000)^2+fuel.cp(4)*(T/1000)^3+fuel.cp(5)*(T/1000)^4+fuel.cp(6)*(T/1000)^5;
    cp_cyl_1  = cp_a_1*GE_CATG3508.x_air_int + cp_sg_1*GE_CATG3508.x_sg_int + cp_fuel_1*GE_CATG3508.x_f_int;
    cv_cyl_1  = cp_cyl_1-R_cyl;
    kappa_cyl_1 = cp_cyl_1 / cv_cyl_1;
    
    % thermodynamic properties T2
    T = GE_CATG3508.T2;
    cp_a_2 = air.cp(1)+air.cp(2)*(T/1000)+air.cp(3)*(T/1000)^2+air.cp(4)*(T/1000)^3+air.cp(5)*(T/1000)^4+air.cp(6)*(T/1000)^5;
    cp_sg_2 = sg.cp(1)+sg.cp(2)*(T/1000)+sg.cp(3)*(T/1000)^2+sg.cp(4)*(T/1000)^3+sg.cp(5)*(T/1000)^4+sg.cp(6)*(T/1000)^5;
    cp_fuel_2 = fuel.cp(1)+fuel.cp(2)*(T/1000)+fuel.cp(3)*(T/1000)^2+fuel.cp(4)*(T/1000)^3+fuel.cp(5)*(T/1000)^4+fuel.cp(6)*(T/1000)^5;
    cp_cyl_2  = cp_a_2*GE_CATG3508.x_air_int + cp_sg_2*GE_CATG3508.x_sg_int + cp_fuel_2*GE_CATG3508.x_f_int;
    cv_cyl_2  = cp_cyl_2-R_cyl;
    kappa_cyl_2 = cp_cyl_2 / cv_cyl_2;
    %average cv at 1-2
    cv_cyl_12 = 0.5*(cv_cyl_1 + cv_cyl_2);
    
    % specific work 1-2
    GE_CATG3508.w12       = -cv_cyl_12*(GE_CATG3508.T2-GE_CATG3508.T1);    % [J] negative work, output of compression process 1-2; per cycle per cylinder per kilo working fluid

% process 2-3; constant-volume combustion 
    GE_CATG3508.p3_int    = GE_CATG3508.p2_int*GE_CATG3508.a;      % [Pa] pressure after constant-volume combustion
    GE_CATG3508.T3_int    = GE_CATG3508.a*GE_CATG3508.T2;          % [K] temperature after constant-volume combustion
    GE_CATG3508.V3        = GE_CATG3508.V2;                        % [m3] volume after constant-volume combustion
    
    % thermodynamic properties T3
    T=GE_CATG3508.T3_int;
    cp_a_3 = air.cp(1)+air.cp(2)*(T/1000)+air.cp(3)*(T/1000)^2+air.cp(4)*(T/1000)^3+air.cp(5)*(T/1000)^4+air.cp(6)*(T/1000)^5;
    cp_sg_3 = sg.cp(1)+sg.cp(2)*(T/1000)+sg.cp(3)*(T/1000)^2+sg.cp(4)*(T/1000)^3+sg.cp(5)*(T/1000)^4+sg.cp(6)*(T/1000)^5;
    cp_fuel_3 = fuel.cp(1)+fuel.cp(2)*(T/1000)+fuel.cp(3)*(T/1000)^2+fuel.cp(4)*(T/1000)^3+fuel.cp(5)*(T/1000)^4+fuel.cp(6)*(T/1000)^5;
    cp_cyl_3  = cp_a_3*GE_CATG3508.x_air_int + cp_sg_3*GE_CATG3508.x_sg_int + cp_fuel_3*GE_CATG3508.x_f_int;
    cv_cyl_3  = cp_cyl_3-R_cyl;
    kappa_cyl_3 = cp_cyl_3 / cv_cyl_3;
    % average cv at 2-3
    cv_cyl_23 = 0.5*(cv_cyl_2 + cv_cyl_3);
    
    % specific heat 2-3
    GE_CATG3508.q_cv_int  = cv_cyl_23*(GE_CATG3508.T3_int-GE_CATG3508.T2);    % [J/kg,cyc,cyl] specific heat release at constant-volume combustion period; per cycle per cylinder per kilo working fluid	
       
% process 3-4, constant-pressure combustion	
    GE_CATG3508.T4_int    = GE_CATG3508.T3_int * GE_CATG3508.b;            % [K] temperature after constant-pressure combustion
    GE_CATG3508.V4_int    = GE_CATG3508.b*GE_CATG3508.V3;                  % [m3] volume after constant-pressure combustion
	GE_CATG3508.p4_int    = GE_CATG3508.p3_int;                            % [Pa] pressure of constant-pressure combustion
	GE_CATG3508.w34_int   = R_cyl*(GE_CATG3508.T4_int-GE_CATG3508.T3_int); % [J/kg] work, output of constant-pressure combustion; per cycle per cylinder per kilo working fluid
    
    % thermodynamic properties T4
    T=GE_CATG3508.T4_int;
    cp_a_4 = air.cp(1)+air.cp(2)*(T/1000)+air.cp(3)*(T/1000)^2+air.cp(4)*(T/1000)^3+air.cp(5)*(T/1000)^4+air.cp(6)*(T/1000)^5;
    cp_sg_4 = sg.cp(1)+sg.cp(2)*(T/1000)+sg.cp(3)*(T/1000)^2+sg.cp(4)*(T/1000)^3+sg.cp(5)*(T/1000)^4+sg.cp(6)*(T/1000)^5;
    cp_fuel_4 = fuel.cp(1)+fuel.cp(2)*(T/1000)+fuel.cp(3)*(T/1000)^2+fuel.cp(4)*(T/1000)^3+fuel.cp(5)*(T/1000)^4+fuel.cp(6)*(T/1000)^5;
    cp_cyl_4  = cp_a_4*GE_CATG3508.x_air_int + cp_sg_4*GE_CATG3508.x_sg_int + cp_fuel_4*GE_CATG3508.x_f_int;
    cv_cyl_4  = cp_cyl_4-R_cyl;
    kappa_cyl_4 = cp_cyl_4 / cv_cyl_4;
    % average cp at 3-4
    cp_cyl_34 = 0.5*(cp_cyl_3 + cp_cyl_4);
     
    % specific heat 3-4
    GE_CATG3508.q_cp_int  = cp_cyl_34*(GE_CATG3508.T4_int-GE_CATG3508.T3_int);% [kJ/kg,cyc,cyl] specific heat relaese at constant-pressure combustion period; per cycle per cylinder per kilo mass flow
   
% process 4-5, isothermal combustion
    GE_CATG3508.p5_int    = GE_CATG3508.p4_int/GE_CATG3508.c;               % [Pa] pressure of constant-temperature combustion
    GE_CATG3508.T5_int    = GE_CATG3508.T4_int;                             % [K] temperature after constant-temperature combustion
    GE_CATG3508.V5_int    = GE_CATG3508.V4_int*GE_CATG3508.c;               % [m3] volume after constant-temperature combustion
    GE_CATG3508.w45_int   = R_cyl*GE_CATG3508.T4_int*log(GE_CATG3508.c);    % [J/kg] work, output of constant-temperature combustion; per cycle per cylinder per kilo working fluid
    GE_CATG3508.q_ct_int  = R_cyl*GE_CATG3508.T4_int*log(GE_CATG3508.c);    % [kJ/kg,cyc,cyl] specific heat relaese at constant-temperature combustion period; per cycle per cylinder per kilo mass flow

% Seiliger Heat ratios    
    GE_CATG3508.q_tot = GE_CATG3508.q_cv_int + GE_CATG3508.q_cp_int + GE_CATG3508.q_ct_int;
    GE_CATG3508.q_23_ratio = GE_CATG3508.q_cv_int/GE_CATG3508.q_tot;
    GE_CATG3508.q_34_ratio = GE_CATG3508.q_cp_int/GE_CATG3508.q_tot;
    GE_CATG3508.q_45_ratio = GE_CATG3508.q_ct_int/GE_CATG3508.q_tot;
    GE_CATG3508.q_56_ratio = 0;
    
% proces 5-6, polytropic expension
%     GE_CATG3508.r_eo      = GE_CATG3508.L_EO/GE_CATG3508.L_IC;              % Ratio of volume at Seiliger point 6
    GE_CATG3508.r_e       = GE_CATG3508.V_EO/GE_CATG3508.V5_int;              % Expansion ratio
%     GE_CATG3508.V6        = GE_CATG3508.V5_int *(GE_CATG3508.r_eo*GE_CATG3508.r_c/(GE_CATG3508.b*GE_CATG3508.c));                        % [m3] volume after expansion
    GE_CATG3508.V6        = GE_CATG3508.V_EO;
%     GE_CATG3508.p6_int    = GE_CATG3508.p5_int/((GE_CATG3508.r_eo*GE_CATG3508.r_c/(GE_CATG3508.b*GE_CATG3508.c))^GE_CATG3508.n_exp);     % [Pa] pressure after expansion
%     GE_CATG3508.T6_int    = GE_CATG3508.T5_int/((GE_CATG3508.r_eo*GE_CATG3508.r_c/(GE_CATG3508.b*GE_CATG3508.c))^(GE_CATG3508.n_exp-1)); % [K] temperature expansion
    GE_CATG3508.p6_int    = GE_CATG3508.p5_int/((GE_CATG3508.r_e)^(GE_CATG3508.n_exp));     % [Pa] pressure after expansion
    GE_CATG3508.p6_nom    = 4.911*10^5;     % [Pa] pressure after expansion
    GE_CATG3508.T6_int    = GE_CATG3508.T5_int/((GE_CATG3508.r_e)^(GE_CATG3508.n_exp-1)); % [K] temperature expansion
    GE_CATG3508.T6_nom    = 959.8; % [K] temperature expansion
    GE_CATG3508.w56_int   = -R_cyl*(GE_CATG3508.T6_int-GE_CATG3508.T5_int)/(GE_CATG3508.n_exp-1);% [J/kg], work, output of polytropic expension; per cycle per cylinder per kilo working fluid

% total work	
    GE_CATG3508.w_i_int   = GE_CATG3508.w12 + GE_CATG3508.w34_int + GE_CATG3508.w45_int + GE_CATG3508.w56_int;  %[J/kg/cycle] Specific work per cycle
	GE_CATG3508.W_cyc_est = GE_CATG3508.w_i_int*GE_CATG3508.m1_int;                                             %[J/cycle] Work per cycle
    GE_CATG3508.IPC_est = GE_CATG3508.W_cyc_est*((GE_CATG3508.i*GE_CATG3508.n_nom)/GE_CATG3508.k);
    GE_CATG3508.GE_loss_est = GE_CATG3508.IPC_est*GE_CATG3508.Wlossgexh_ratio;
    GE_CATG3508.IP_est = GE_CATG3508.IPC_est - GE_CATG3508.GE_loss_est;
    GE_CATG3508.Power_est = (GE_CATG3508.IP_est*GE_CATG3508.eta_m*GE_CATG3508.eta_gen)/1000;
    
    