GE_CATG3508.name  = 'GE_CATG3508';         % engine data designation

% General engine parameter package
GE_CATG3508.P_nom  = 375;               % [kW] rated output power of the engine 
GE_CATG3508.D_B    = 0.17;              % [m] bore diameter
GE_CATG3508.L_S    = 0.19;              % [m] stroke length
GE_CATG3508.N_nom  = 1500;              % [rpm] rated speed of engine (rpm = rotations per minute)
GE_CATG3508.n_nom  = GE_CATG3508.N_nom/60;  % [Hz] rated speed of engine
GE_CATG3508.i      = 8;                 % [-] number of cylinders
GE_CATG3508.k      = 2;                 % [-] two stroke = 1; four stroke = 2
GE_CATG3508.eps    = 12;               % [-] geometric compression ratio
GE_CATG3508.V_s    = pi/4*GE_CATG3508.D_B^2*GE_CATG3508.L_S;              % [m] stroke length
GE_CATG3508.V_TDC  = GE_CATG3508.V_s/(GE_CATG3508.eps-1);                 % [m3]
GE_CATG3508.V_BDC  = GE_CATG3508.V_s + GE_CATG3508.V_TDC;                 % [m3]

GE_CATG3508.IC = 21.5;                  % Relative to ABDC1
GE_CATG3508.IO = 360 + 180 + 8.702;     % Relative to ABDC1
GE_CATG3508.EO = 360-20.1;              % Relative to ABDC1
GE_CATG3508.EC = 360 + 180 - 11.826;    % Relative to ABDC1
GE_CATG3508.alfa_IC = (GE_CATG3508.IC)*(pi/180);       % ATDC1
GE_CATG3508.alfa_IO = (GE_CATG3508.IO)*(pi/180);
GE_CATG3508.alfa_EO = (GE_CATG3508.EO)*(pi/180);       % ATDC2
GE_CATG3508.alfa_EC = (GE_CATG3508.EC)*(pi/180);

GE_CATG3508.L_CR         = 0.816;             % [m]  Length crank rod
GE_CATG3508.lambda_CR    = 0.5*GE_CATG3508.L_S/GE_CATG3508.L_CR;             % [m]  Length crank rod
GE_CATG3508.f            = (GE_CATG3508.i*GE_CATG3508.n_nom)/GE_CATG3508.k; 
GE_CATG3508.V_IC = GE_CATG3508.V_s*(1/(GE_CATG3508.eps-1)+0.5*((1-cos(GE_CATG3508.alfa_IC+pi))+(1-sqrt(1-(GE_CATG3508.lambda_CR*sin(GE_CATG3508.alfa_IC+pi))^2))/GE_CATG3508.lambda_CR)); % (m3)
GE_CATG3508.V_EC = GE_CATG3508.V_s*(1/(GE_CATG3508.eps-1)+0.5*((1-cos(GE_CATG3508.alfa_EC+pi))+(1-sqrt(1-(GE_CATG3508.lambda_CR*sin(GE_CATG3508.alfa_EC+pi))^2))/GE_CATG3508.lambda_CR)); % (m3)
GE_CATG3508.V_IO = GE_CATG3508.V_s*(1/(GE_CATG3508.eps-1)+0.5*((1-cos(GE_CATG3508.alfa_IO+pi))+(1-sqrt(1-(GE_CATG3508.lambda_CR*sin(GE_CATG3508.alfa_IC+pi))^2))/GE_CATG3508.lambda_CR)); % (m3)
GE_CATG3508.V_EO = GE_CATG3508.V_s*(1/(GE_CATG3508.eps-1)+0.5*((1-cos(GE_CATG3508.alfa_EO+pi))+(1-sqrt(1-(GE_CATG3508.lambda_CR*sin(GE_CATG3508.alfa_EO+pi))^2))/GE_CATG3508.lambda_CR)); % (m3)
GE_CATG3508.r_c       = GE_CATG3508.V_IC/GE_CATG3508.V_TDC;                                                  % [-] effective compression ration
GE_CATG3508.x         = (GE_CATG3508.V_IC - GE_CATG3508.V_TDC)/GE_CATG3508.V_s; 
% Losses
GE_CATG3508.eta_m = 0.90;           % [-] mechanical efficiency at nominal point
% GE_CATG3508.eta_gen = 0.95;         % [-] generator mechancial efficiency at nominal point   
Load_ratio = [Load/GE_CATG3508.P_nom];
GE_CATG3508.eta_gen = (-0.2758*(Load_ratio^-0.4344))+1.231;         % [-] generator mechancial efficiency at nominal point   
% GE_CATG3508.Wlossgexh_ratio = 0.0445; % [-] Percentage work loss due to gas exchange (pumping loss)
GE_CATG3508.Wlossgexh_ratio = (0.03447*(Load_ratio^-0.8546))+0.01314; % [-] Percentage work loss due to gas exchange (pumping loss)
GE_CATG3508.eta_scav  = 1;              % [-] scavenge efficiency

% In-Cylinder nominal performance data
GE_CATG3508.p_max     = 65e5;           % [Pa] estimated max cylinder pressure at nominal point
GE_CATG3508.p_d_nom   = 1.81215e5;      % [Pa] nominal exhaust receiver pressure (Harsh p_7)

% Slip calculation
GE_CATG3508.s     = 0;  % No slip


%%% Fuel mass and flow rate
x_L = Load/500;                               % Input for Regression

% Only Natural gas fuel regression (Benchmark) + Regression input
p1_L =       1.117;
p2_L =      0.1621;
NGFM_norm = p1_L*x_L + p2_L;

NGMF_norm = 2.902985000000000e-04;            % 

m_NG = NGFM_norm*NGMF_norm;                   % Only Natural gas fuel mass (Benchmark)
NG_FLR = NGFM_norm*NGMF_norm*(3600*GE_CATG3508.f)/rho_NG; % Only Natural Gas flow rate (Benchmark)

% Fuel Blend
x = NGFM_norm;                                     % Input for Regression

if strcmp(HCO2,'0')==1;
    y_CO2 = CO2_f/100;
    y_H = H_f/100
elseif strcmp(HCO2,'1')==1;
    y_CO2 = CO2_f/100;
    y_H = H_f/100
elseif strcmp(HCO2,'2')==1;
    y_CO2 = CO2_f/100;
    y_H = H_f/100
else strcmp(HCO2,'3')==1;
    y_CO2 = (CO2_f/100)/(1-((CO2_f/100)+(H_f/100)));   % relative CO2
    y_H = (H_f/100)/(1-((CO2_f/100)+(H_f/100)));       % relative H
end

%%% NGMF %CO2
p00_NGMFCO2 =  1.888e-06; 
p10_NGMFCO2 = -2.812e-06;
p01_NGMFCO2 =  8.688e-06;
p20_NGMFCO2 =  8.605e-07;
p11_NGMFCO2 =  8.285e-06;
p02_NGMFCO2 = -3.919e-05;

D_NGMFCO2 = p00_NGMFCO2 + p10_NGMFCO2*x + p01_NGMFCO2*y_CO2 + p20_NGMFCO2*x^2 + p11_NGMFCO2*x*y_CO2 + p02_NGMFCO2*y_CO2^2; % Delta Natural Gas mass for CO2 blend
m_NG_CO2 = m_NG + D_NGMFCO2;
% NGFLR_CO2 = m_NG_CO2*(3600*GE_CATG3508.f)/rho_NG; % Natural Gas flow for CO2 blend

%%% NGMF %H
p00_NGMFH = 4.493e-06;
p10_NGMFH = -1.01e-05;
p01_NGMFH = -1.08e-05;
p20_NGMFH =  5.834e-06;
p11_NGMFH = -0.0001505;
p02_NGMFH =  6.273e-05;

D_NGMFH = p00_NGMFH + p10_NGMFH*x + p01_NGMFH*y_H + p20_NGMFH*x^2 + p11_NGMFH*x*y_H + p02_NGMFH*y_H^2; % Delta Natural Gas mass for H2 blend
m_NG_H = m_NG + D_NGMFH;

% NGFLR_H = m_NG_H*(3600*GE_CATG3508.f)/rho_NG;    % Natural Gas flow for H2 blend

m_NG_HCO2 = m_NG + D_NGMFH  + D_NGMFCO2; % Final natural gas mass [kg] Engine

if strcmp(HCO2,'0')==1;
    GE_CATG3508.m_NG_final = m_NG;
elseif strcmp(HCO2,'1')==1;
    GE_CATG3508.m_NG_final = m_NG_H;
elseif strcmp(HCO2,'2')==1;
    GE_CATG3508.m_NG_final = m_NG_CO2;
else strcmp(HCO2,'3')==1;
    GE_CATG3508.m_NG_final = m_NG_HCO2;
end
     

GE_CATG3508.Q_NG_FLR = GE_CATG3508.m_NG_final*(3600*GE_CATG3508.f)/rho_NG;    % Final Natural Gas flow [m3/hr] Engine
GE_CATG3508.Q_Fuel = GE_CATG3508.Q_NG_FLR/(NG_f/100);            % Total Fuel flow [m3/hr] Engine
GE_CATG3508.Q_H_FLR = (H_f/100)*GE_CATG3508.Q_Fuel;              % Hydrogen Fuel flow [m3/hr] Engine
GE_CATG3508.Q_CO2_FLR = (CO2_f/100)*GE_CATG3508.Q_Fuel;          % Carbon Dioxide Fuel flow [m3/hr] Engine

GE_CATG3508.m_H =  ((GE_CATG3508.Q_H_FLR/3600)*rho_H)/GE_CATG3508.f; % mass of hydrogen fuel per cycle per cylinder
GE_CATG3508.m_CO2 =  ((GE_CATG3508.Q_CO2_FLR/3600)*rho_CO2)/GE_CATG3508.f; % mass of carbon dioxide fuel per cycle per cylinder
GE_CATG3508.m_NG =  ((GE_CATG3508.Q_NG_FLR/3600)*rho_NG)/GE_CATG3508.f; % mass of natural gas fuel per cycle per cylinder

GE_CATG3508.m_Fuel =  ((GE_CATG3508.Q_Fuel/3600)*fuel.rho)/GE_CATG3508.f; % mass of fuel per cycle per cylinder

GE_CATG3508.m_f = GE_CATG3508.m_Fuel;
% Dimensions, source: CAT3508 industrial engine brochure
GE_CATG3508.h      = 1.7196;      % [m] height engine 
GE_CATG3508.l      = 2.1358;      % [m] lenght engine
GE_CATG3508.w      = 1.703;       % [m] width engine
GE_CATG3508.m      = 4611;        % [kg] dry weight engine
GE_CATG3508.volume = GE_CATG3508.h*GE_CATG3508.l*GE_CATG3508.w;  % [m3] volume engine

GE_CATG3508.TEnergyIN = ((GE_CATG3508.Q_Fuel/3600)*fuel.rho)*(fuel.h_L/1000);
EnergyONG = GE_CATG3508.TEnergyIN - ((GE_CATG3508.Q_H_FLR/3600)*rho_H)*((LHV.x_H*0.037234*1000)/(rho_H));
