function Y = Load2fuel(u)
%%% Fuel mass and flow rate
z_L2F = u(1)/500;                               % Input for Regression



i = 8;
n = 1500/60;
k = 2;
f = (i*n)/k;

rho_NG = 0.8469;

% Only Natural gas fuel regression (Benchmark) + Regression input
p1_L2F =       1.117;
p2_L2F =      0.1621;
NGFM_norm_L2F = p1_L2F*z_L2F + p2_L2F;

NGMF_norm = 2.902985000000000e-04;            % 

m_NG_L2F = NGFM_norm_L2F*NGMF_norm;                   % Only Natural gas fuel mass (Benchmark)
NG_FLR_L2F = NGFM_norm_L2F*NGMF_norm*(3600*GE_CATG3508.f)/rho_NG; % Only Natural Gas flow rate (Benchmark)

% Fuel Blend
x_L2F = NGFM_norm_L2F;                                     % Input for Regression

if strcmp(HCO2,'0')==1;
    y_CO2_L2F = CO2_f/100;
    y_H_L2F = H_f/100
elseif strcmp(HCO2,'1')==1;
    y_CO2_L2F = CO2_f/100;
    y_H_L2F = H_f/100
elseif strcmp(HCO2,'2')==1;
    y_CO2_L2F = CO2_f/100;
    y_H_L2F = H_f/100
else strcmp(HCO2,'3')==1;
    y_CO2_L2F = (CO2_f/100)/(1-((CO2_f/100)+(H_f/100)));   % relative CO2
    y_H_L2F = (H_f/100)/(1-((CO2_f/100)+(H_f/100)));       % relative H
end

%%% NGMF %CO2
p00_NGMFCO2_L2F =  1.888e-06; 
p10_NGMFCO2_L2F = -2.812e-06;
p01_NGMFCO2_L2F =  8.688e-06;
p20_NGMFCO2_L2F =  8.605e-07;
p11_NGMFCO2_L2F =  8.285e-06;
p02_NGMFCO2_L2F = -3.919e-05;

D_NGMFCO2_L2F = p00_NGMFCO2_L2F + p10_NGMFCO2_L2F*x_L2F + p01_NGMFCO2_L2F*y_CO2_L2F + p20_NGMFCO2_L2F*x_L2F^2 + p11_NGMFCO2_L2F*x_L2F*y_CO2_L2F + p02_NGMFCO2_L2F*y_CO2_L2F^2; % Delta Natural Gas mass for CO2 blend
m_NG_L2F_CO2 = m_NG_L2F + D_NGMFCO2_L2F;
% NGFLR_CO2 = m_NG_L2F_CO2*(3600*GE_CATG3508.f)/rho_NG; % Natural Gas flow for CO2 blend

%%% NGMF %H
p00_NGMFH_L2F = 4.493e-06;
p10_NGMFH_L2F = -1.01e-05;
p01_NGMFH_L2F = -1.08e-05;
p20_NGMFH_L2F =  5.834e-06;
p11_NGMFH_L2F = -0.0001505;
p02_NGMFH_L2F =  6.273e-05;

D_NGMFH_L2F = p00_NGMFH_L2F + p10_NGMFH_L2F*x_L2F + p01_NGMFH_L2F*y_H_L2F + p20_NGMFH_L2F*x_L2F^2 + p11_NGMFH_L2F*x_L2F*y_H_L2F + p02_NGMFH_L2F*y_H_L2F^2; % Delta Natural Gas mass for H2 blend
m_NG_L2F_H = m_NG_L2F + D_NGMFH_L2F;

% NGFLR_H = m_NG_L2F_H*(3600*GE_CATG3508.f)/rho_NG;    % Natural Gas flow for H2 blend

m_NG_L2F_HCO2 = m_NG_L2F + D_NGMFH_L2F  + D_NGMFCO2_L2F; % Final natural gas mass [kg] Engine

if strcmp(HCO2,'0')==1;
    m_NG_L2F_final = m_NG_L2F;
elseif strcmp(HCO2,'1')==1;
    m_NG_L2F_final = m_NG_L2F_H;
elseif strcmp(HCO2,'2')==1;
    m_NG_L2F_final = m_NG_L2F_CO2;
else strcmp(HCO2,'3')==1;
    m_NG_L2F_final = m_NG_L2F_HCO2;
end
     

Q_NG_FLR_L2F = m_NG_L2F_final*(3600*GE_CATG3508.f)/rho_NG;    % Final Natural Gas flow [m3/hr] Engine
Q_Fuel_L2F = Q_NG_FLR_L2F/(NG_f/100);            % Total Fuel flow [m3/hr] Engine

m_Fuel_L2F =  ((Q_Fuel_L2F/3600)*GE_CATG3508.fuel.rho)/f; % mass of fuel per cycle per cylinder




Y = [m_Fuel_L2F ];
