%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PROPERTIES OF AIR AND STOICHIOMETRIC GAS AND FUEL (R, Cp)                               % 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
%% Choices for Taylor fit 

        T_shift = 0;                    % Develop cp around 0 Kelvin
        T_norm  = 1000;                 % [K] Normalize temperatures
     
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Parameters for air and stoichiometric gas
    % Molair masses
        gas.M = [M(14)*2, M(16)*2, M(40), M(12)+M(16)*2, M(1)*2+M(16), M(32)+M(16)*2];
        gas.R = 1000*R_u./gas.M	;       %[J/kg], [N2,O2,Ar,CO2,H2O,SO2]
    % Volume and mass fractions in normal dry air 
        air.y_N2  = 0.7809;
        air.y_O2  = 0.2095;
        air.y_Ar  = 0.0093;
        air.y_CO2 = 0.0003;
        
        
        air.M = air.y_N2*gas.M(1) + air.y_O2*gas.M(2) + air.y_Ar*gas.M(3) + air.y_CO2*gas.M(4);
        
        air.x_N2 =gas.M(1)/air.M*air.y_N2;
        air.x_O2 =gas.M(2)/air.M*air.y_O2;
        air.x_Ar =gas.M(3)/air.M*air.y_Ar;
        air.x_CO2 =gas.M(4)/air.M*air.y_CO2;
        
        air.y_H2O =air.M/gas.M(4)*air.x_CO2;
        
        air.R = air.x_N2*gas.R(1) + air.x_O2*gas.R(2) + air.x_Ar*gas.R(3) + air.x_CO2*gas.R(4);
    
        CO2.R = gas.R(4);
     % Coefficients of polynominal functions to calculate cp_air and cp_g
     
        N2.cp  = [3.5463	-0.5773	1.8224	-1.1149	0.2731	-0.0239];   %[-] data Sta
        O2.cp  = [3.0845	1.8622	-1.0049	0.2817	-0.0320	0.0007];    %[-] data Sta
        Ar.cp  = [2.500	    0.000	0.000	0.000	0.000	0.000];     %[-] data Sta
        CO2.cp = [2.5468	8.0614	-5.9398	2.2908	-0.4380	0.0327];    %[-] data Sta
        H2O.cp = [3.9800	-0.4380	2.5797	-1.4469	0.3244	-0.0264];   %[-] data Sta
        SO2.cp = [2.7915	8.9226	-8.4591	4.1789	-1.0431	0.1038];    %[-] data Sta
        
        N2.cp  = N2.cp*gas.R(1);       %[J/kg/K]
        O2.cp  = O2.cp*gas.R(2);       %[J/kg/K]
        Ar.cp  = Ar.cp*gas.R(3);       %[J/kg/K]
        CO2.cp = CO2.cp*gas.R(4);     %[J/kg/K]
        H2O.cp = H2O.cp*gas.R(5);     %[J/kg/K]
        SO2.cp = SO2.cp*gas.R(6);     %[J/kg/K]
    % Stoichiometric ratio
fuel.sigma  =(air.M/air.y_O2)*(fuel.x_C/M(12) + fuel.x_H/M(1)/4 + fuel.x_S/M(32));
      
    % Coefficients of polynomimal functions to calculate cp_air and cp_g in [J/kg/K]
        T_ref = T_CK + 25;             % [K]    ref temp is 25 C
        p_ref = 100000;                % [Pa]   ref press is 1 bar
    
        N2.h(1)=0;
        O2.h(1)=0;
        Ar.h(1)=0;
        CO2.h(1)=0;
        H2O.h(1)=0;
        SO2.h(1)=0;
              
        for k = 1:6
            
            N2.h(k+1)=N2.cp(k)/k*T_norm;
            N2.h(1)=N2.h(1)-(N2.h(k+1)*(T_ref/T_norm)^k);
            O2.h(k+1)=O2.cp(k)/k*T_norm;
            O2.h(1)=O2.h(1)-(O2.h(k+1)*(T_ref/T_norm)^k);
            Ar.h(k+1)=Ar.cp(k)/k*T_norm;
            Ar.h(1)=Ar.h(1)-(Ar.h(k+1)*(T_ref/T_norm)^k);
            CO2.h(k+1)=CO2.cp(k)/k*T_norm;
            CO2.h(1)=CO2.h(1)-(CO2.h(k+1)*(T_ref/T_norm)^k);
            H2O.h(k+1)=H2O.cp(k)/k*T_norm;
            H2O.h(1)=H2O.h(1)-(H2O.h(k+1)*(T_ref/T_norm)^k);
            SO2.h(k+1)=SO2.cp(k)/k*T_norm;
            SO2.h(1)=SO2.h(1)-(SO2.h(k+1)*(T_ref/T_norm)^k);
                 
        end
        
        N2.s(1)=0;
        O2.s(1)=0;
        Ar.s(1)=0;
        CO2.s(1)=0;
        H2O.s(1)=0;
        SO2.s(1)=0;
        
        for k = 2:6
            
            N2.s(k)=N2.cp(k)/(k-1);
            N2.s(1)=N2.s(1)-(N2.s(k)*(T_ref/T_norm)^(k-1));
            O2.s(k)=O2.cp(k)/(k-1);
            O2.s(1)=O2.s(1)-(O2.s(k)*(T_ref/T_norm)^(k-1));
            Ar.s(k)=Ar.cp(k)/(k-1);
            Ar.s(1)=Ar.s(1)-(Ar.s(k)*(T_ref/T_norm)^(k-1));
            CO2.s(k)=CO2.cp(k)/(k-1);
            CO2.s(1)=CO2.s(1)-(CO2.s(k)*(T_ref/T_norm)^(k-1));
            H2O.s(k)=H2O.cp(k)/(k-1);
            H2O.s(1)=H2O.s(1)-(H2O.s(k)*(T_ref/T_norm)^(k-1));
            SO2.s(k)=SO2.cp(k)/(k-1);
            SO2.s(1)=SO2.s(1)-(SO2.s(k)*(T_ref/T_norm)^(k-1));
        end    
        
        N2.h_ref = 0;                       %[J/kg} from Baehr 1989 in kJ/mol
        O2.h_ref = 0;                       %[J/kg} from Baehr 1989 in kJ/mol
        Ar.h_ref = 0;                       %[J/kg} from Baehr 1989 in kJ/mol
        CO2.h_ref = -393.509/gas.M(4)*1e+6; %[J/kg} from Baehr 1989 in kJ/mol
        H2O.h_ref = -241.818/gas.M(5)*1e+6; %[J/kg} from Baehr 1989 in kJ/mol(gas)
        SO2.h_ref = -296.83/gas.M(6)*1e+6;  %[J/kg} from Baehr 1989 in kJ/mol
        
        N2.s_ref = 191.61/gas.M(1)*1000;    %[J/kgK} from Baehr 1989 in J/molK
        O2.s_ref = 205.138/gas.M(2)*1000;   %[J/kgK} from Baehr 1989 in J/molK
        Ar.s_ref = 154.843/gas.M(3)*1000;   %[J/kgK} from Baehr 1989 in J/molK
        CO2.s_ref = 213.74/gas.M(4)*1000;   %[J/kgK} from Baehr 1989 in J/molK
        H2O.s_ref = 188.825/gas.M(5)*1000;  %[J/kgK} from Baehr 1989 in J/molK gas
        SO2.s_ref = 248.22/gas.M(6)*1000;   %[J/kgK} from Baehr 1989 in J/molK
            
    % Mass and volume fractions in stoichiometric gas sg
sg.x_N2 = (air.x_N2 * fuel.sigma/(fuel.sigma+1))+ (fuel.x_N2/(fuel.sigma+1));             % massfraction N2 in stoich.g
sg.x_Ar = air.x_Ar * fuel.sigma/(fuel.sigma+1);             % massfraction N2 in stoich.g
sg.x_CO2 = (gas.M(4)/M(12)*fuel.x_C + fuel.x_CO2)/(fuel.sigma+1);
sg.x_H2O = gas.M(5)/M(1)/2*fuel.x_H/(fuel.sigma+1);         % massfr. H2O in sg
sg.x_SO2 = gas.M(6)/M(32)*fuel.x_S/(fuel.sigma+1);          % massfr. SO2 in sg
    
sg.M = 1/(sg.x_N2/gas.M(1) + sg.x_Ar/gas.M(3) + sg.x_CO2/gas.M(4) + sg.x_H2O/gas.M(5) + sg.x_SO2/gas.M(6));
        
sg.y_N2 = sg.M/gas.M(1)*sg.x_N2;
sg.y_Ar = sg.M/gas.M(3)*sg.x_Ar;
sg.y_CO2 = sg.M/gas.M(4)*sg.x_CO2;
sg.y_H2O = sg.M/gas.M(5)*sg.x_H2O;
sg.y_SO2 = sg.M/gas.M(6)*sg.x_SO2;
        
% Specific heat & enthalpy of sg and air
        sg.R     = sg.x_N2*gas.R(1) + sg.x_Ar*gas.R(3) + sg.x_CO2*gas.R(4) + sg.x_H2O*gas.R(5) + sg.x_SO2*gas.R(6);     
        sg.cp    = sg.x_N2*N2.cp + sg.x_Ar*Ar.cp + sg.x_CO2*CO2.cp + sg.x_H2O*H2O.cp + sg.x_SO2*SO2.cp;
        sg.h     = sg.x_N2*N2.h + sg.x_Ar*Ar.h + sg.x_CO2*CO2.h + sg.x_H2O*H2O.h + sg.x_SO2*SO2.h;
        sg.h_ref = sg.x_N2*N2.h_ref + sg.x_Ar*Ar.h_ref + sg.x_CO2*CO2.h_ref + sg.x_H2O*H2O.h_ref + sg.x_SO2*SO2.h_ref;
        sg.u_ref = sg.h_ref - sg.R*T_ref;
        sg.s     = sg.x_N2*N2.s + sg.x_Ar*Ar.s + sg.x_CO2*CO2.s + sg.x_H2O*H2O.s + sg.x_SO2*SO2.s;
        sg.s_ref = sg.x_N2*N2.s_ref + sg.x_Ar*Ar.s_ref + sg.x_CO2 * CO2.s_ref + sg.x_H2O*H2O.s_ref + sg.x_SO2*SO2.s_ref;
        
        if sg.y_N2 == 0
        sg.yy_N2 = 0;
        else
        sg.yy_N2 = sg.y_N2 *log(sg.y_N2);
        end
        
        if sg.y_Ar == 0
        sg.yy_Ar = 0;
        else
        sg.yy_Ar = sg.y_Ar *log(sg.y_Ar);
        end
        
        if sg.y_CO2 == 0
        sg.yy_CO2 = 0;
        else
        sg.yy_CO2 = sg.y_CO2 *log(sg.y_CO2);
        end
        
        if sg.y_H2O == 0
        sg.yy_H2O = 0;
        else
        sg.yy_H2O = sg.y_H2O *log(sg.y_H2O);
        end
        
        if sg.y_SO2 == 0
        sg.yy_SO2 = 0;
        else
        sg.yy_SO2 = sg.y_SO2 *log(sg.y_SO2);
        end
        
        sg.s_mix =-sg.R*(sg.yy_N2 + sg.yy_Ar + sg.yy_CO2 + sg.yy_H2O + sg.yy_SO2);
        sg.s_ref_tot = sg.s_ref + sg.s_mix;
           
        air.cp    = air.x_N2*N2.cp + air.x_O2 * O2.cp + air.x_Ar*Ar.cp + air.x_CO2*CO2.cp;
        air.h     = air.x_N2*N2.h + air.x_O2 * O2.h + air.x_Ar*Ar.h + air.x_CO2*CO2.h;
        air.h_ref = air.x_N2*N2.h_ref + air.x_O2 * O2.h_ref + air.x_Ar* Ar.h_ref + air.x_CO2*CO2.h_ref;
        air.u_ref = air.h_ref - air.R*T_ref;
        air.s     = air.x_N2*N2.s + air.x_O2 * O2.s + air.x_Ar*Ar.s + air.x_CO2*CO2.s;
        air.s_ref = air.x_N2*N2.s_ref + air.x_O2 * O2.s_ref + air.x_Ar* Ar.s_ref + air.x_CO2*CO2.s_ref;
        
        if air.y_N2 == 0
        air.yy_N2 = 0;
        else       
        air.yy_N2  = air.y_N2*log(air.y_N2);
        end
        
        if air.y_O2 == 0
        air.yy_O2 = 0;
        else
        air.yy_O2  = air.y_O2*log(air.y_O2);
        end
        
        if air.y_Ar == 0
        air.yy_Ar = 0;
        else
        air.yy_Ar  = air.y_Ar*log(air.y_Ar);
        end
        
        if air.y_CO2 == 0
        air.yy_CO2 = 0;
        else
        air.yy_CO2  = air.y_CO2*log(air.y_CO2);
        end
        
        air.s_mix =-air.R*(air.yy_N2 + air.yy_O2 + air.yy_Ar + air.yy_CO2);
        air.s_ref_tot = air.s_ref + air.s_mix;
     
%% Parameters fuel     
fuel.M              = (fuel.y_N2.*MM_N2) + (fuel.y_CO2.*MM_CO2) + fuel.y_CH4.*MM_CH4 + fuel.y_C2H6.*MM_C2H6 + fuel.y_C3H8.*MM_C3H8 + fuel.y_iC4H10.*MM_iC4H10 + fuel.y_nC4H10.*MM_nC4H10 + fuel.y_iC5H12.*MM_iC5H12 + fuel.y_nC5H12.*MM_nC5H12 + fuel.y_nC6H14.*MM_nC6H14 + fuel.y_H.*MM_H + fuel.y_He.*MM_He + (fuel.y_neoC5H12.*MM_neoC5H12);
NGH.M = (fuel.y_N2.*MM_N2) + fuel.y_CH4.*MM_CH4 + fuel.y_C2H6.*MM_C2H6 + fuel.y_C3H8.*MM_C3H8 + fuel.y_iC4H10.*MM_iC4H10 + fuel.y_nC4H10.*MM_nC4H10 + fuel.y_iC5H12.*MM_iC5H12 + fuel.y_nC5H12.*MM_nC5H12 + fuel.y_nC6H14.*MM_nC6H14 + fuel.y_H.*MM_H + fuel.y_He.*MM_He + (fuel.y_neoC5H12.*MM_neoC5H12);
fuel.R = 1000*R_u./fuel.M;          % [J/kg/K]
NGH.R = 1000*R_u./NGH.M;          % [J/kg/K]
          
% Cp Calculations
Temp1 = [300:50:1000]';
Temp2 = [1050:50:2050]';
Temp = [Temp1; Temp2];


% NASA Coefficients
% CH4
a_CH4 = [5.14987613; -1.36709788E-02;	4.91800599E-05;	-4.84743026E-08; 1.66693956E-11];
b_CH4 = [1.63552643;  1.00842795E-02;	-3.36916254E-06;	5.34958667E-10;	-3.15518833E-14];
% C2H6
a_C2H6 = [4.29142492;	-5.50154270E-03;	5.99438288E-05;	-7.08466285E-08;	2.68685771E-11];
b_C2H6 = [4.04666674;	 1.53538766E-02;   -5.47039321E-06;	 8.77826228E-10;	-5.23167305E-14];
% CO2
a_CO2 = [2.35677352;	8.98459677E-03;	-7.12356269E-06;	2.45919022E-09;	-1.43699548E-13];
b_CO2 = [4.63659493;	2.74131991E-03;	-9.95828531E-07;	1.60373011E-10;	-9.16103468E-15];
%H2
a_H2 = [2.34433112;	7.98052075E-03;	-1.94781510E-05;	2.01572094E-08;	-7.37611761E-12];
b_H2 = [2.93286579;	8.26607967E-04;	-1.46402335E-07;	1.54100359E-11;	-6.88804432E-16];
%N2
a_N2 = [3.53100528;	-1.23660987E-04;	-5.02999437E-07;	2.43530612E-09;	-1.40881235E-12];
b_N2 = [2.95257626;	 1.39690057E-03;	-4.92631691E-07;	7.86010367E-11;	-4.60755321E-15];


% Cp kJ/kmolK    
% CH4    
Cp_CH41 = (a_CH4(1)+(a_CH4(2).*Temp1)+(a_CH4(3).*(Temp1.^2))+(a_CH4(4).*(Temp1.^3))+(a_CH4(5).*(Temp1.^4))).*R_u;
Cp_CH42 = (b_CH4(1)+(b_CH4(2).*Temp2)+(b_CH4(3).*(Temp2.^2))+(b_CH4(4).*(Temp2.^3))+(b_CH4(5).*(Temp2.^4))).*R_u;
% C2H6
Cp_C2H61 = (a_C2H6(1)+(a_C2H6(2).*Temp1)+(a_C2H6(3).*(Temp1.^2))+(a_C2H6(4).*(Temp1.^3))+(a_C2H6(5).*(Temp1.^4))).*R_u;
Cp_C2H62 = (b_C2H6(1)+(b_C2H6(2).*Temp2)+(b_C2H6(3).*(Temp2.^2))+(b_C2H6(4).*(Temp2.^3))+(b_C2H6(5).*(Temp2.^4))).*R_u;
%CO2
Cp_CO21 = (a_CO2(1)+(a_CO2(2).*Temp1)+(a_CO2(3).*(Temp1.^2))+(a_CO2(4).*(Temp1.^3))+(a_CO2(5).*(Temp1.^4))).*R_u;
Cp_CO22 = (b_CO2(1)+(b_CO2(2).*Temp2)+(b_CO2(3).*(Temp2.^2))+(b_CO2(4).*(Temp2.^3))+(b_CO2(5).*(Temp2.^4))).*R_u;
%H2
Cp_H21 = (a_H2(1)+(a_H2(2).*Temp1)+(a_H2(3).*(Temp1.^2))+(a_H2(4).*(Temp1.^3))+(a_H2(5).*(Temp1.^4))).*R_u;
Cp_H22 = (b_H2(1)+(b_H2(2).*Temp2)+(b_H2(3).*(Temp2.^2))+(b_H2(4).*(Temp2.^3))+(b_H2(5).*(Temp2.^4))).*R_u;
%N2
Cp_N21 = (a_N2(1)+(a_N2(2).*Temp1)+(a_N2(3).*(Temp1.^2))+(a_N2(4).*(Temp1.^3))+(a_N2(5).*(Temp1.^4))).*R_u;
Cp_N22 = (b_N2(1)+(b_N2(2).*Temp2)+(b_N2(3).*(Temp2.^2))+(b_N2(4).*(Temp2.^3))+(b_N2(5).*(Temp2.^4))).*R_u;


% Cp kJ/kgK
%CH4
Cp_CH41 = Cp_CH41./MM_CH4;
Cp_CH42 = Cp_CH42./MM_CH4;
%C2H6
Cp_C2H61 = Cp_C2H61./MM_C2H6;
Cp_C2H62 = Cp_C2H62./MM_C2H6;
%CO2
Cp_CO21 = Cp_CO21./MM_CO2;
Cp_CO22 = Cp_CO22./MM_CO2;
%H2
Cp_H21 = Cp_H21./MM_H;
Cp_H22 = Cp_H22./MM_H;
%N2
Cp_N21 = Cp_N21./MM_N2;
Cp_N22 = Cp_N22./MM_N2;

% Total Mass of Fuel for Cp calculations: Correction bcoz slightly less than 1
Total_mass_for_Cp =  fuel.x_N2+fuel.x_CO2+fuel.x_CH4+fuel.x_C2H6+fuel.x_H2;
fuel.X_CH4_Cp = fuel.x_CH4./Total_mass_for_Cp;
fuel.X_C2H6_Cp = fuel.x_C2H6./Total_mass_for_Cp;
fuel.X_CO2_Cp = fuel.x_CO2./Total_mass_for_Cp;
fuel.X_H2_Cp = fuel.x_H2./Total_mass_for_Cp;
fuel.X_N2_Cp = fuel.x_N2./Total_mass_for_Cp;

Total_Normalized_and_corrected_mass_for_Cp = fuel.X_CH4_Cp + fuel.X_C2H6_Cp + fuel.X_CO2_Cp + fuel.X_H2_Cp + fuel.X_N2_Cp;

Cp_1 = [(Cp_CH41.*fuel.X_CH4_Cp) + (Cp_C2H61.*fuel.X_C2H6_Cp) + (Cp_CO21*fuel.X_CO2_Cp) + (Cp_H21.*fuel.X_H2_Cp) + (Cp_N21.*fuel.X_N2_Cp)];
Cp_2 = [(Cp_CH42.*fuel.X_CH4_Cp) + (Cp_C2H62.*fuel.X_C2H6_Cp) + (Cp_CO22*fuel.X_CO2_Cp) + (Cp_H22.*fuel.X_H2_Cp) + (Cp_N22.*fuel.X_N2_Cp)];

Cp = [Cp_1; Cp_2];

Temp = Temp./1000;
Cp = Cp.*1000;

coef_cp = polyfit(Temp,Cp,5);
coef_cp = fliplr(coef_cp);

fuel.cp = coef_cp;
  
        
% Internal energy and enthalpy of fuel
        fuel.u_l(1)=0;
        for k = 1:6    
            fuel.u_l(k+1)=fuel.cp(k)/k*T_norm;
            fuel.u_l(1)=fuel.u_l(1)-(fuel.u_l(k+1)*(T_ref/T_norm)^k);         
        end
        fuel.h(1)=0;
        for k = 1:6    
            fuel.h(k+1)=fuel.cp(k)/k*T_norm;
            fuel.h(1)=fuel.h(1)-(fuel.h(k+1)*(T_ref/T_norm)^k);
        end
% Reference values of internal energy and enthalpy
        fuel.h_ref      = fuel.h_comb + (fuel.sigma+1)* sg.h_ref - fuel.sigma * air.h_ref;
        fuel.rho_ref    = fuel.rho_15-fuel.rho_T_cor*(T_ref-15); % [kg/m3] fuel density at ref temp
        fuel.u_ref      = fuel.h_ref-p_ref/fuel.rho_ref;   % Incompressible: density at 15 is equal to density at 25
        fuel.u_comb     = fuel.h_comb - (fuel.h_ref-fuel.u_ref) - (air.h_ref-air.u_ref)*fuel.sigma + (sg.h_ref-sg.u_ref)*(fuel.sigma+1);
        fuel.U_0        = fuel.u_comb/1000; % [kJ/kg]

% Evaporation heat fuel at ref temperature 
        fuel.h_evap     = 0;       
       
%% Parameters for heat conduction coefficient and viscosity of air
%         
        gas.par_lambda_l    = [27.88e-3,0.75];              % Labda = c1 * T^c2, Zaph, 1969
        gas.par_eta_l       = [19.67e-6,0.62];              % Viscositeit Zaph, 1969
        
        
        